==> haskell-hslua-aeson-2.3.1.1-35-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-hslua-aeson.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 hslua-aeson
version:              2.3.1.1
visibility:           public
id:                   hslua-aeson-2.3.1.1-4I4B2V2IkUEITHAajzDnkY
key:                  hslua-aeson-2.3.1.1-4I4B2V2IkUEITHAajzDnkY
license:              MIT
copyright:            © 2017–2024 Albert Krewinkel
maintainer:           Albert Krewinkel <tarleb@hslua.org>
author:               Albert Krewinkel
homepage:             https://hslua.org/
synopsis:             Allow aeson data types to be used with Lua.
description:
    This package provides instances to push and receive any
    datatype encodable as JSON to and from the Lua stack.

category:             Foreign
abi:                  a7641f8a1718b02e39b01c4ba1758e04
exposed:              True
exposed-modules:      HsLua.Aeson
import-dirs:          /usr/lib/ghc-9.4.8/site-local/hslua-aeson-2.3.1.1
library-dirs:         /usr/lib/ghc-9.4.8/site-local/hslua-aeson-2.3.1.1
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/hslua-aeson-2.3.1.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-hslua-aeson
hs-libraries:         HShslua-aeson-2.3.1.1-4I4B2V2IkUEITHAajzDnkY
depends:
    aeson-2.1.2.1-9rGsBPhyshTKvPzkopJx8r base-4.17.2.1
    bytestring-0.11.5.3 containers-0.6.7
    hashable-1.4.7.0-LvsgkXc0RJl9ehxeji9DTo
    hslua-core-2.3.2-8emlurBj6p2Aob8sqI9gdj
    hslua-marshalling-2.3.1-L67LuUMHNHO1Z9pS9RRTxm mtl-2.2.2
    scientific-0.3.8.0-GtjUIC3j80u95XeMq22yYk text-2.0.2
    unordered-containers-0.2.20.1-LlrDkEbe6ka5Vid8Nf7fMl
    vector-0.13.2.0-9W9rHKyBrY08EKASla5WO0

haddock-interfaces:   /usr/share/doc/haskell-hslua-aeson/html/hslua-aeson.haddock
haddock-html:         /usr/share/doc/haskell-hslua-aeson/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-hslua-aeson-2.3.1.1-36-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-hslua-aeson.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 hslua-aeson
version:              2.3.1.1
visibility:           public
id:                   hslua-aeson-2.3.1.1-GbaMCzO7bQOJIUICPVN05g
key:                  hslua-aeson-2.3.1.1-GbaMCzO7bQOJIUICPVN05g
license:              MIT
copyright:            © 2017–2024 Albert Krewinkel
maintainer:           Albert Krewinkel <tarleb@hslua.org>
author:               Albert Krewinkel
homepage:             https://hslua.org/
synopsis:             Allow aeson data types to be used with Lua.
description:
    This package provides instances to push and receive any
    datatype encodable as JSON to and from the Lua stack.

category:             Foreign
abi:                  db2ad425ef5c4d5eb0a06113008a9e98
exposed:              True
exposed-modules:      HsLua.Aeson
import-dirs:          /usr/lib/ghc-9.4.8/site-local/hslua-aeson-2.3.1.1
library-dirs:         /usr/lib/ghc-9.4.8/site-local/hslua-aeson-2.3.1.1
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/hslua-aeson-2.3.1.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-hslua-aeson
hs-libraries:         HShslua-aeson-2.3.1.1-GbaMCzO7bQOJIUICPVN05g
depends:
    aeson-2.1.2.1-3LOl3stht3x9JybSpHkoQT base-4.17.2.1
    bytestring-0.11.5.3 containers-0.6.7
    hashable-1.4.7.0-bh6X3bZPF56LQTYQ27khw
    hslua-core-2.3.2-Ddk7ag4CTKFBmSZbu5NijL
    hslua-marshalling-2.3.1-3ZOm1AiZhyNHhKTd4aQWAn mtl-2.2.2
    scientific-0.3.8.0-APNnjCxblnoKMeXmBXkKkr text-2.0.2
    unordered-containers-0.2.20.1-98Hg6PuNW0XDqLHXL1727Z
    vector-0.13.2.0-24VaMY7coOLw3wI0c1W3K

haddock-interfaces:   /usr/share/doc/haskell-hslua-aeson/html/hslua-aeson.haddock
haddock-html:         /usr/share/doc/haskell-hslua-aeson/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
